@@ -7,7 +7,7 @@ package Sub::HandlesVia;
 use Exporter::Shiny qw( delegations );
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.035';
+our $VERSION   = '0.036';
 
 sub _generate_delegations {
 	my ($me, $name, $args, $globals) = (shift, @_);
@@ -421,176 +421,183 @@ array index.)
 The following table compares Sub::HandlesVia with L<Data::Perl>, L<Moose>
 native traits, and L<MouseX::NativeTraits>.
 
-  Array ===========================================
-            accessor : SubHV  DataP  Moose  Mouse  
-                 all : SubHV  DataP                
-            all_true : SubHV                       
-                 any : SubHV                Mouse  
-               apply : SubHV                Mouse  
-               clear : SubHV  DataP  Moose  Mouse  
-               count : SubHV  DataP  Moose  Mouse  
-              delete : SubHV  DataP  Moose  Mouse  
-            elements : SubHV  DataP  Moose  Mouse  
-               fetch :                      Mouse  (alias: get)
-               first : SubHV  DataP  Moose  Mouse  
-         first_index : SubHV  DataP  Moose         
-             flatten : SubHV  DataP                
-        flatten_deep : SubHV  DataP                
-            for_each : SubHV                Mouse  
-       for_each_pair : SubHV                Mouse  
-                 get : SubHV  DataP  Moose  Mouse  
-                grep : SubHV  DataP  Moose  Mouse  
-                head : SubHV  DataP                
-              insert : SubHV  DataP  Moose  Mouse  
-            is_empty : SubHV  DataP  Moose  Mouse  
-                join : SubHV  DataP  Moose  Mouse  
-                 map : SubHV  DataP  Moose  Mouse  
-                 max : SubHV                       
-              maxstr : SubHV                       
-                 min : SubHV                       
-              minstr : SubHV                       
-            natatime : SubHV  DataP  Moose         
-        not_all_true : SubHV                       
-           pairfirst : SubHV                       
-            pairgrep : SubHV                       
-            pairkeys : SubHV                       
-             pairmap : SubHV                       
-               pairs : SubHV                       
-          pairvalues : SubHV                       
-         pick_random : SubHV                       
-                 pop : SubHV  DataP  Moose  Mouse  
-               print : SubHV  DataP                
-             product : SubHV                       
-                push : SubHV  DataP  Moose  Mouse  
-              reduce : SubHV  DataP  Moose  Mouse  
-          reductions : SubHV                       
-              remove :                      Mouse  (alias: delete)
-               reset : SubHV                       
-             reverse : SubHV  DataP                
-              sample : SubHV                       
-                 set : SubHV  DataP  Moose  Mouse  
-       shallow_clone : SubHV  DataP  Moose         
-               shift : SubHV  DataP  Moose  Mouse  
-             shuffle : SubHV  DataP  Moose  Mouse  
-    shuffle_in_place : SubHV                       
-                sort : SubHV  DataP  Moose  Mouse  
-             sort_by :                      Mouse  (sort)
-       sort_in_place : SubHV  DataP  Moose  Mouse  
-    sort_in_place_by :                      Mouse  (sort_in_place)
-              splice : SubHV  DataP  Moose  Mouse  
-               store :                      Mouse  (alias: set)
-                 sum : SubHV                       
-                tail : SubHV  DataP                
-                uniq : SubHV  DataP  Moose  Mouse  
-       uniq_in_place : SubHV                       
-             uniqnum : SubHV                       
-    uniqnum_in_place : SubHV                       
-             uniqstr : SubHV                       
-    uniqstr_in_place : SubHV                       
-             unshift : SubHV  DataP  Moose  Mouse  
+  Array ==============================================
+               accessor : SubHV  DataP  Moose  Mouse  
+                    all : SubHV  DataP                
+               all_true : SubHV                       
+                    any : SubHV                Mouse  
+                  apply : SubHV                Mouse  
+                  clear : SubHV  DataP  Moose  Mouse  
+                  count : SubHV  DataP  Moose  Mouse  
+                 delete : SubHV  DataP  Moose  Mouse  
+               elements : SubHV  DataP  Moose  Mouse  
+                  fetch :                      Mouse  (alias: get)
+                  first : SubHV  DataP  Moose  Mouse  
+            first_index : SubHV  DataP  Moose         
+                flatten : SubHV  DataP                
+           flatten_deep : SubHV  DataP                
+               for_each : SubHV                Mouse  
+          for_each_pair : SubHV                Mouse  
+                    get : SubHV  DataP  Moose  Mouse  
+                   grep : SubHV  DataP  Moose  Mouse  
+                   head : SubHV  DataP                
+                 insert : SubHV  DataP  Moose  Mouse  
+               is_empty : SubHV  DataP  Moose  Mouse  
+                   join : SubHV  DataP  Moose  Mouse  
+                    map : SubHV  DataP  Moose  Mouse  
+                    max : SubHV                       
+                 maxstr : SubHV                       
+                    min : SubHV                       
+                 minstr : SubHV                       
+               natatime : SubHV  DataP  Moose         
+           not_all_true : SubHV                       
+              pairfirst : SubHV                       
+               pairgrep : SubHV                       
+               pairkeys : SubHV                       
+                pairmap : SubHV                       
+                  pairs : SubHV                       
+             pairvalues : SubHV                       
+            pick_random : SubHV                       
+                    pop : SubHV  DataP  Moose  Mouse  
+                  print : SubHV  DataP                
+                product : SubHV                       
+                   push : SubHV  DataP  Moose  Mouse  
+                 reduce : SubHV  DataP  Moose  Mouse  
+             reductions : SubHV                       
+                 remove :                      Mouse  (alias: delete)
+                  reset : SubHV                       
+                reverse : SubHV  DataP                
+                 sample : SubHV                       
+                    set : SubHV  DataP  Moose  Mouse  
+          shallow_clone : SubHV  DataP  Moose         
+                  shift : SubHV  DataP  Moose  Mouse  
+                shuffle : SubHV  DataP  Moose  Mouse  
+       shuffle_in_place : SubHV                       
+                   sort : SubHV  DataP  Moose  Mouse  
+                sort_by :                      Mouse  (sort)
+          sort_in_place : SubHV  DataP  Moose  Mouse  
+       sort_in_place_by :                      Mouse  (sort_in_place)
+                 splice : SubHV  DataP  Moose  Mouse  
+                  store :                      Mouse  (alias: set)
+                    sum : SubHV                       
+                   tail : SubHV  DataP                
+                   uniq : SubHV  DataP  Moose  Mouse  
+          uniq_in_place : SubHV                       
+                uniqnum : SubHV                       
+       uniqnum_in_place : SubHV                       
+                uniqstr : SubHV                       
+       uniqstr_in_place : SubHV                       
+                unshift : SubHV  DataP  Moose  Mouse  
   
-  Bool ============================================
-                 not : SubHV  DataP  Moose  Mouse  
-               reset : SubHV                       
-                 set : SubHV  DataP  Moose  Mouse  
-              toggle : SubHV  DataP  Moose  Mouse  
-               unset : SubHV  DataP  Moose  Mouse  
+  Bool ===============================================
+                    not : SubHV  DataP  Moose  Mouse  
+                  reset : SubHV                       
+                    set : SubHV  DataP  Moose  Mouse  
+                 toggle : SubHV  DataP  Moose  Mouse  
+                  unset : SubHV  DataP  Moose  Mouse  
   
-  Code ============================================
-             execute : SubHV  DataP  Moose  Mouse  
-      execute_method : SubHV         Moose  Mouse  
+  Code ===============================================
+                execute : SubHV  DataP  Moose  Mouse  
+           execute_list : SubHV             ..........
+         execute_scalar : SubHV             ..........
+           execute_void : SubHV             ..........
+         execute_method : SubHV         Moose  Mouse  
+    execute_method_list : SubHV             ..........
+  execute_method_scalar : SubHV             ..........
+    execute_method_void : SubHV             ..........
   
-  Counter =========================================
-                 dec : SubHV  DataP  Moose  Mouse  
-                 inc : SubHV  DataP  Moose  Mouse  
-               reset : SubHV  DataP  Moose  Mouse  
-                 set : SubHV         Moose  Mouse  
+  Counter ============================================
+                    dec : SubHV  DataP  Moose  Mouse  
+                    inc : SubHV  DataP  Moose  Mouse  
+                  reset : SubHV  DataP  Moose  Mouse  
+                    set : SubHV         Moose  Mouse  
   
-  Hash ============================================
-            accessor : SubHV  DataP  Moose  Mouse  
-                 all : SubHV  DataP                
-               clear : SubHV  DataP  Moose  Mouse  
-               count : SubHV  DataP  Moose  Mouse  
-             defined : SubHV  DataP  Moose  Mouse  
-              delete : SubHV  DataP  Moose  Mouse  
-            elements : SubHV  DataP  Moose  Mouse  
-              exists : SubHV  DataP  Moose  Mouse  
-               fetch :                      Mouse  (alias: get)
-        for_each_key : SubHV                Mouse  
-       for_each_pair : SubHV                Mouse  
-      for_each_value : SubHV                Mouse  
-                 get : SubHV  DataP  Moose  Mouse  
-            is_empty : SubHV  DataP  Moose  Mouse  
-                keys : SubHV  DataP  Moose  Mouse  
-                  kv : SubHV  DataP  Moose  Mouse  
-               reset : SubHV                       
-                 set : SubHV  DataP  Moose  Mouse  
-       shallow_clone : SubHV  DataP  Moose         
-         sorted_keys : SubHV                Mouse  
-               store :                      Mouse  (alias: set)
-              values : SubHV  DataP  Moose  Mouse  
+  Hash ===============================================
+               accessor : SubHV  DataP  Moose  Mouse  
+                    all : SubHV  DataP                
+                  clear : SubHV  DataP  Moose  Mouse  
+                  count : SubHV  DataP  Moose  Mouse  
+                defined : SubHV  DataP  Moose  Mouse  
+                 delete : SubHV  DataP  Moose  Mouse  
+           delete_where : SubHV                       
+               elements : SubHV  DataP  Moose  Mouse  
+                 exists : SubHV  DataP  Moose  Mouse  
+                  fetch :                      Mouse  (alias: get)
+           for_each_key : SubHV                Mouse  
+          for_each_pair : SubHV                Mouse  
+         for_each_value : SubHV                Mouse  
+                    get : SubHV  DataP  Moose  Mouse  
+               is_empty : SubHV  DataP  Moose  Mouse  
+                   keys : SubHV  DataP  Moose  Mouse  
+                     kv : SubHV  DataP  Moose  Mouse  
+                  reset : SubHV                       
+                    set : SubHV  DataP  Moose  Mouse  
+          shallow_clone : SubHV  DataP  Moose         
+            sorted_keys : SubHV                Mouse  
+                  store :                      Mouse  (alias: set)
+                 values : SubHV  DataP  Moose  Mouse  
   
-  Number ==========================================
-                 abs : SubHV  DataP  Moose  Mouse  
-                 add : SubHV  DataP  Moose  Mouse  
-                 cmp : SubHV                       
-                 div : SubHV  DataP  Moose  Mouse  
-                  eq : SubHV                       
-                  ge : SubHV                       
-                 get : SubHV                       
-                  gt : SubHV                       
-                  le : SubHV                       
-                  lt : SubHV                       
-                 mod : SubHV  DataP  Moose  Mouse  
-                 mul : SubHV  DataP  Moose  Mouse  
-                  ne : SubHV                       
-                 set : SubHV         Moose         
-                 sub : SubHV  DataP  Moose  Mouse  
+  Number =============================================
+                    abs : SubHV  DataP  Moose  Mouse  
+                    add : SubHV  DataP  Moose  Mouse  
+                    cmp : SubHV                       
+                    div : SubHV  DataP  Moose  Mouse  
+                     eq : SubHV                       
+                     ge : SubHV                       
+                    get : SubHV                       
+                     gt : SubHV                       
+                     le : SubHV                       
+                     lt : SubHV                       
+                    mod : SubHV  DataP  Moose  Mouse  
+                    mul : SubHV  DataP  Moose  Mouse  
+                     ne : SubHV                       
+                    set : SubHV         Moose         
+                    sub : SubHV  DataP  Moose  Mouse  
   
-  Scalar ==========================================
-         make_getter : SubHV                       
-         make_setter : SubHV                       
-    scalar_reference : SubHV                       
+  Scalar =============================================
+            make_getter : SubHV                       
+            make_setter : SubHV                       
+       scalar_reference : SubHV                       
   
-  String ==========================================
-              append : SubHV  DataP  Moose  Mouse  
-               chomp : SubHV  DataP  Moose  Mouse  
-                chop : SubHV  DataP  Moose  Mouse  
-               clear : SubHV  DataP  Moose  Mouse  
-                 cmp : SubHV                       
-                cmpi : SubHV                       
-            contains : SubHV                       
-          contains_i : SubHV                       
-           ends_with : SubHV                       
-         ends_with_i : SubHV                       
-                  eq : SubHV                       
-                 eqi : SubHV                       
-                  fc : SubHV                       
-                  ge : SubHV                       
-                 gei : SubHV                       
-                 get : SubHV                       
-                  gt : SubHV                       
-                 gti : SubHV                       
-                 inc : SubHV  DataP  Moose  Mouse  
-                  lc : SubHV                       
-                  le : SubHV                       
-                 lei : SubHV                       
-              length : SubHV  DataP  Moose  Mouse  
-                  lt : SubHV                       
-                 lti : SubHV                       
-               match : SubHV  DataP  Moose  Mouse  
-             match_i : SubHV                       
-                  ne : SubHV                       
-                 nei : SubHV                       
-             prepend : SubHV  DataP  Moose  Mouse  
-             replace : SubHV  DataP  Moose  Mouse  
-    replace_globally : SubHV                Mouse  
-               reset : SubHV                       
-                 set : SubHV                       
-         starts_with : SubHV                       
-       starts_with_i : SubHV                       
-              substr : SubHV  DataP  Moose  Mouse  
-                  uc : SubHV                       
+  String =============================================
+                 append : SubHV  DataP  Moose  Mouse  
+                  chomp : SubHV  DataP  Moose  Mouse  
+                   chop : SubHV  DataP  Moose  Mouse  
+                  clear : SubHV  DataP  Moose  Mouse  
+                    cmp : SubHV                       
+                   cmpi : SubHV                       
+               contains : SubHV                       
+             contains_i : SubHV                       
+              ends_with : SubHV                       
+            ends_with_i : SubHV                       
+                     eq : SubHV                       
+                    eqi : SubHV                       
+                     fc : SubHV                       
+                     ge : SubHV                       
+                    gei : SubHV                       
+                    get : SubHV                       
+                     gt : SubHV                       
+                    gti : SubHV                       
+                    inc : SubHV  DataP  Moose  Mouse  
+                     lc : SubHV                       
+                     le : SubHV                       
+                    lei : SubHV                       
+                 length : SubHV  DataP  Moose  Mouse  
+                     lt : SubHV                       
+                    lti : SubHV                       
+                  match : SubHV  DataP  Moose  Mouse  
+                match_i : SubHV                       
+                     ne : SubHV                       
+                    nei : SubHV                       
+                prepend : SubHV  DataP  Moose  Mouse  
+                replace : SubHV  DataP  Moose  Mouse  
+       replace_globally : SubHV                Mouse  
+                  reset : SubHV                       
+                    set : SubHV                       
+            starts_with : SubHV                       
+          starts_with_i : SubHV                       
+                 substr : SubHV  DataP  Moose  Mouse  
+                     uc : SubHV                       
 
 For further details see:
 L<Array|Sub::HandlesVia::HandlerLibrary::Array>,
