@@ -7,7 +7,7 @@
 
     our $USES_MITE    = "Mite::Class";
     our $MITE_SHIM    = "Sub::HandlesVia::Mite";
-    our $MITE_VERSION = "0.010002";
+    our $MITE_VERSION = "0.010005";
 
     # Mite keywords
     BEGIN {
@@ -56,7 +56,6 @@
     # Gather metadata for constructor and destructor
     sub __META__ {
         no strict 'refs';
-        no warnings 'once';
         my $class = shift;
         $class = ref($class) || $class;
         my $linear_isa = mro::get_linear_isa($class);
@@ -552,7 +551,7 @@
         return;
     }
 
-    my $__XS = !$ENV{MITE_PURE_PERL}
+    my $__XS = !$ENV{PERL_ONLY}
       && eval { require Class::XSAccessor; Class::XSAccessor->VERSION("1.19") };
 
     # Accessors for _examples
@@ -934,7 +933,7 @@
 
     our $USES_MITE    = "Mite::Class";
     our $MITE_SHIM    = "Sub::HandlesVia::Mite";
-    our $MITE_VERSION = "0.010002";
+    our $MITE_VERSION = "0.010005";
 
     # Mite keywords
     BEGIN {
@@ -1436,7 +1435,7 @@
         return $self;
     }
 
-    my $__XS = !$ENV{MITE_PURE_PERL}
+    my $__XS = !$ENV{PERL_ONLY}
       && eval { require Class::XSAccessor; Class::XSAccessor->VERSION("1.19") };
 
     # Accessors for name
@@ -1479,7 +1478,7 @@
 
     our $USES_MITE    = "Mite::Class";
     our $MITE_SHIM    = "Sub::HandlesVia::Mite";
-    our $MITE_VERSION = "0.010002";
+    our $MITE_VERSION = "0.010005";
 
     # Mite keywords
     BEGIN {
@@ -1995,7 +1994,7 @@
         return $self;
     }
 
-    my $__XS = !$ENV{MITE_PURE_PERL}
+    my $__XS = !$ENV{PERL_ONLY}
       && eval { require Class::XSAccessor; Class::XSAccessor->VERSION("1.19") };
 
     # Accessors for delegated_coderef
